<!-- SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com> -->
<!-- SPDX-License-Identifier: CC-BY-4.0 -->

# Planned Changes

The following API-breaking changes are planned or in consideration:
* Rename some utility functions or make them private.
